@@ -2,6 +2,7 @@ from typing import Any, Mapping
 import asyncio
 from datetime import date, datetime
 from importlib import resources
+import json
 
 from graphql import GraphQLField, GraphQLObjectType, GraphQLInterfaceType, GraphQLResolveInfo
 from ariadne import load_schema_from_path, make_executable_schema, SchemaDirectiveVisitor, FallbackResolversSetter, \
@@ -186,6 +187,19 @@ def parse_datetime(value: str):
     return date.fromisoformat(value)
 
 
+json_scalar = ScalarType("Json")
+
+
+@json_scalar.serializer
+def serialize_json(value: dict):
+    json.dumps(value)
+
+
+@json_scalar.value_parser
+def parse_json(value: str):
+    return json.loads(value)
+
+
 # Fallback Resolver
 
 def strict_default_field_resolver(source: Any, info: GraphQLResolveInfo, **args: Any) -> Any:
@@ -235,14 +249,17 @@ def create_graphql(schema_path, bindables: list[SchemaBindable], debug: bool):
     with resources.path('st_microservice', 'base.graphql') as common_filename:
         type_defs_common = load_schema_from_path(common_filename)
 
-    schema = make_executable_schema([type_defs, type_defs_common], bindables, model_types, date_scalar, datetime_scalar, fallback_resolvers, directives={
-        'no_authentication': NoAuthenticationDirective,
-        'need_permission': NeedPermissionDirective,
-        'db_model': DBModelDirective,
-        'all_filter': AllFilterDirective,
-        'filter': FilterDirective,
-        'no_filter': NoFilterDirective
-    })
+    schema = make_executable_schema(
+        [type_defs, type_defs_common], bindables, model_types, date_scalar, datetime_scalar, json_scalar,
+        fallback_resolvers, directives={
+            'no_authentication': NoAuthenticationDirective,
+            'need_permission': NeedPermissionDirective,
+            'db_model': DBModelDirective,
+            'all_filter': AllFilterDirective,
+            'filter': FilterDirective,
+            'no_filter': NoFilterDirective
+        }
+    )
 
     return GraphQL(
         schema,
