@@ -9,7 +9,7 @@ from pypika.queries import QueryBuilder
 from aiodataloader import DataLoader
 
 from .database import LockedDB
-from .exceptions import NoRowsError, MultipleRowsError
+from .exceptions import NoRowsError, MultipleRowsError, DatabaseQueryError
 from .request_utils import get_state
 
 
@@ -78,11 +78,13 @@ class BaseModel:
     @classmethod
     def primary_key_filter(cls, primary_keys: Sequence) -> pypika.Criterion:
         """ Return Criterion to be used in a .where() """
+        if not len(primary_keys):
+            raise DatabaseQueryError("Primary key filter must have at least one value")
         conditions = [getattr(cls.f, cls.primary_keys[i]) == pk_value for i, pk_value in enumerate(primary_keys)]
         return pypika.Criterion.all(conditions)
 
     @classmethod
-    def get_query(cls, primary_keys: Sequence):
+    def get_query(cls, primary_keys: Sequence) -> QueryBuilder:
         """ Primary keys can be Params """
         q = cls.registry.query_class.from_(cls.t).select(*cls.fs).where(cls.primary_key_filter(primary_keys))
         return q
@@ -108,6 +110,21 @@ class BaseModel:
             raise NoRowsError
         return row
 
+    @classmethod
+    def delete_query(cls, primary_keys: Sequence) -> QueryBuilder:
+        """ Primary keys can be Params """
+        if len(primary_keys) != len(cls.primary_keys):
+            raise DatabaseQueryError("Primary keys argument in BaseModel.delete_query() must match BaseModel's in length")
+        q = cls.registry.query_class.from_(cls.t).delete().where(cls.primary_key_filter(primary_keys))
+        return q
+
+    @classmethod
+    async def delete(cls, db: Connection | LockedDB, primary_keys: Sequence) -> None:
+        """ Primary keys need to be real values """
+        pk_params = [pypika.Parameter(f'${i + 1}') for i in range(len(primary_keys))]
+        q = cls.delete_query(pk_params)
+        await db.execute(q, *primary_keys)
+
     @classmethod
     def insert_query(
             cls,
