@@ -1,5 +1,6 @@
 from pypika import CustomFunction, Criterion
 from pypika.terms import ValueWrapper
+from pypika.queries import QueryBuilder
 
 
 Exists = CustomFunction('EXISTS', ['subquery'])
@@ -17,3 +18,12 @@ class Any(Criterion):
             array=self.array.get_sql(**kwargs)
         )
         return sql
+
+
+class SubQuery(Criterion):
+    def __init__(self, val: str | QueryBuilder):
+        super().__init__()
+        self.val = val
+
+    def get_sql(self, **kwargs) -> str:
+        return f'({self.val})'
