@@ -13,7 +13,7 @@ def get_request(info: GraphQLResolveInfo) -> Request:
 
 
 def get_user(info: GraphQLResolveInfo) -> User:
-    return get_request(info.context).user
+    return get_request(info).user
 
 
 def get_state(info: GraphQLResolveInfo) -> State:
